@@ -12,21 +12,19 @@ config() {
 
 config etc/ssh/ssh_config.new
 config etc/ssh/sshd_config.new
+config etc/rc.d/rc.sshd.new
 
-# If the sshd user/group don't exist, add them:
-if grep "^sshd:x:" etc/passwd 1> /dev/null 2> /dev/null ; then
-  true
-else
+# If the sshd user/group/shadow don't exist, add them:
+
+if ! grep -q "^sshd:" etc/passwd ; then
   echo "sshd:x:33:33:sshd:/:" >> etc/passwd
 fi
-if grep "^sshd::" etc/group 1> /dev/null 2> /dev/null ; then
-  true
-else
+
+if ! grep -q "^sshd:" etc/group ; then
   echo "sshd::33:sshd" >> etc/group
 fi
-if grep "^sshd:" etc/shadow 1> /dev/null 2> /dev/null ; then
-  true
-else
+
+if ! grep -q "^sshd:" etc/shadow ; then
   echo "sshd:*:9797:0:::::" >> etc/shadow
 fi
 
